@@ -8,20 +8,20 @@
 
 namespace newsbeuter {
 
+typedef std::pair<std::string, unsigned int> google_replay_pair;
+enum { GOOGLE_MARK_READ = 1, GOOGLE_MARK_UNREAD = 2 };
+
 class cache {
 	public:
 		cache(const std::string& cachefile, configcontainer * c);
 		~cache();
 		void externalize_rssfeed(std::tr1::shared_ptr<rss_feed> feed, bool reset_unread);
 		void internalize_rssfeed(std::tr1::shared_ptr<rss_feed> feed, rss_ignores * ign);
-		void update_rssitem(std::tr1::shared_ptr<rss_item> item, const std::string& feedurl, bool reset_unread);
 		void update_rssitem_unread_and_enqueued(std::tr1::shared_ptr<rss_item> item, const std::string& feedurl);
 		void update_rssitem_unread_and_enqueued(rss_item* item, const std::string& feedurl);
 		void cleanup_cache(std::vector<std::tr1::shared_ptr<rss_feed> >& feeds);
 		void do_vacuum();
-		void get_latest_items(std::vector<std::tr1::shared_ptr<rss_item> >& items, unsigned int limit);
 		std::vector<std::tr1::shared_ptr<rss_item> > search_for_items(const std::string& querystr, const std::string& feedurl);
-		std::tr1::shared_ptr<rss_feed> get_feed_by_url(const std::string& feedurl);
 		void catchup_all(const std::string& feedurl = "");
 		void catchup_all(std::tr1::shared_ptr<rss_feed> feed);
 		void update_rssitem_flags(rss_item* item);
@@ -33,6 +33,10 @@ class cache {
 		void remove_old_deleted_items(const std::string& rssurl, const std::vector<std::string>& guids);
 		void mark_items_read_by_guid(const std::vector<std::string> guids);
 		std::vector<std::string> get_read_item_guids();
+		void fetch_descriptions(rss_feed * feed);
+		void record_google_replay(const std::string& guid, unsigned int state);
+		std::vector<google_replay_pair> get_google_replay();
+		void delete_google_replay_by_guid(const std::vector<std::string>& guids);
 	private:
 		void populate_tables();
 		void set_pragmas();
@@ -47,14 +51,6 @@ class cache {
 		mutex mtx;
 };
 
-class scope_transaction {
-	public:
-		scope_transaction(sqlite3 * db);
-		~scope_transaction();
-	private:
-		sqlite3 * d;
-};
-
 }
 
 
