@@ -18,6 +18,7 @@ namespace newsbeuter {
 
 	class view;
 
+
 	class controller {
 		public:
 			controller();
@@ -45,6 +46,7 @@ namespace newsbeuter {
 			void update_visible_feeds();
 			void mark_all_read(unsigned int pos);
 			void mark_article_read(const std::string& guid, bool read);
+			void record_google_replay(const std::string& guid, bool read);
 			void catchup_all();
 			inline void catchup_all(std::tr1::shared_ptr<rss_feed> feed) { rsscache->catchup_all(feed); }
 			inline bool get_refresh_on_start() { return refresh_on_start; }
@@ -84,6 +86,8 @@ namespace newsbeuter {
 			void update_flags(std::tr1::shared_ptr<rss_item> item);
 		private:
 			void usage(char * argv0);
+			bool setup_dirs_xdg(const char *env_home);
+			void setup_dirs();
 			void version_information(const char * argv0, unsigned int level);
 			void import_opml(const char * filename);
 			void export_opml();
@@ -110,6 +114,8 @@ namespace newsbeuter {
 			std::string cache_file;
 			std::string config_file;
 			std::string queue_file;
+			std::string searchfile;
+			std::string cmdlinefile;
 			bool refresh_on_start;
 			configcontainer cfg;
 			rss_ignores ign;
@@ -121,6 +127,7 @@ namespace newsbeuter {
 			regexmanager rxman;
 			remote_api * api;
 			mutex feeds_mutex;
+			bool offline_mode;
 	};
 
 }
