@@ -3,11 +3,13 @@
 
 #include <fstream>
 #include <mutex.h>
+#include <config.h>
 
 namespace newsbeuter {
 
 	enum loglevel { LOG_NONE = 0, LOG_USERERROR, LOG_CRITICAL, LOG_ERROR, LOG_WARN, LOG_INFO, LOG_DEBUG };
 
+
 class logger {
 	public:
 		logger();
@@ -16,6 +18,7 @@ class logger {
 		void set_errorlogfile(const char * logfile);
 		void set_loglevel(loglevel level);
 		void log(loglevel level, const char * format, ...);
+		inline void nada() { }
 	private:
 		loglevel curlevel;
 		mutex mtx;
@@ -27,4 +30,10 @@ logger& GetLogger();
 
 }
 
+#ifdef NO_DEBUG
+#define LOG(x, ...) do { } while(0)
+#else
+#define LOG(x, ...) do { GetLogger().log(x, __VA_ARGS__); } while(0)
+#endif
+
 #endif
