@@ -29,8 +29,6 @@ namespace newsbeuter {
 			void run();
 			std::string run_modal(std::tr1::shared_ptr<formaction> f, const std::string& value = "");
 
-			std::string id();
-
 			void set_feedlist(std::vector<std::tr1::shared_ptr<rss_feed> > feeds);
 			void update_visible_feeds(std::vector<std::tr1::shared_ptr<rss_feed> > feeds);
 			void set_keymap(keymap * k);
@@ -57,7 +55,7 @@ namespace newsbeuter {
 			void push_searchresult(std::tr1::shared_ptr<rss_feed> feed, const std::string& phrase = "");
 			void view_dialogs();
 
-			std::string run_filebrowser(filebrowser_type type, const std::string& default_filename = "", const std::string& dir = "");
+			std::string run_filebrowser(const std::string& default_filename = "", const std::string& dir = "");
 			std::string select_tag(const std::vector<std::string>& tags);
 			std::string select_filter(const std::vector<filter_name_expr_pair>& filters);
 
@@ -68,10 +66,14 @@ namespace newsbeuter {
 
 			bool get_next_unread(itemlist_formaction * itemlist, itemview_formaction * itemview = NULL);
 			bool get_previous_unread(itemlist_formaction * itemlist, itemview_formaction * itemview = NULL);
+			bool get_next(itemlist_formaction * itemlist, itemview_formaction * itemview = NULL);
+			bool get_previous(itemlist_formaction * itemlist, itemview_formaction * itemview = NULL);
 			bool get_random_unread(itemlist_formaction * itemlist, itemview_formaction * itemview = NULL);
 
 			bool get_next_unread_feed(itemlist_formaction * itemlist);
 			bool get_prev_unread_feed(itemlist_formaction * itemlist);
+			bool get_next_feed(itemlist_formaction * itemlist);
+			bool get_prev_feed(itemlist_formaction * itemlist);
 
 			void set_colors(std::map<std::string,std::string>& fg_colors, std::map<std::string,std::string>& bg_colors, std::map<std::string,std::vector<std::string> >& attributes);
 
