@@ -53,6 +53,7 @@ configcontainer::configcontainer()
 	config_data["cache-file"]      = configdata("", configdata::PATH);
 	config_data["proxy"]           = configdata("", configdata::STR);
 	config_data["proxy-auth"]      = configdata("", configdata::STR);
+	config_data["proxy-auth-method"] = configdata("any", "any", "basic", "digest", "digest_ie", "gssnegotiate", "ntlm", "anysafe", NULL);
 	config_data["confirm-exit"]    = configdata("no", configdata::BOOL);
 	config_data["error-log"]       = configdata("", configdata::PATH);
 	config_data["notify-screen"]   = configdata("no", configdata::BOOL);
@@ -62,9 +63,7 @@ configcontainer::configcontainer()
 	config_data["notify-program"]  = configdata("", configdata::PATH);
 	config_data["notify-format"]   = configdata(_("newsbeuter: finished reload, %f unread feeds (%n unread articles total)"), configdata::STR);
 	config_data["datetime-format"] = configdata("%b %d", configdata::STR);
-	config_data["urls-source"]     = configdata("local", "local", "bloglines", "opml", "googlereader", NULL); // enum
-	config_data["bloglines-auth"]  = configdata("", configdata::STR);
-	config_data["bloglines-mark-read"] = configdata("no", configdata::BOOL);
+	config_data["urls-source"]     = configdata("local", "local", "opml", "googlereader", NULL); // enum
 	config_data["bookmark-cmd"]    = configdata("", configdata::STR);
 	config_data["opml-url"]        = configdata("", configdata::STR, true);
 	config_data["html-renderer"]   = configdata("internal", configdata::PATH);
@@ -98,6 +97,8 @@ configcontainer::configcontainer()
 	config_data["googlereader-show-special-feeds"] = configdata("true", configdata::BOOL);
 	config_data["googlereader-min-items"] = configdata("20", configdata::INT);
 	config_data["ignore-mode"] = configdata("download", "download", "display", NULL); // enum
+	config_data["max-download-speed"] = configdata("0", configdata::INT);
+	config_data["cookie-cache"] = configdata("", configdata::STR);
 
 	/* title formats: */
 	config_data["feedlist-title-format"] = configdata(_("%N %V - Your feeds (%u unread, %t total)%?T? - tag `%T'&?"), configdata::STR);
