@@ -77,23 +77,104 @@ void omg_a_child_died(int /* sig */) {
 	::signal(SIGCHLD, omg_a_child_died); /* in case of unreliable signals */
 }
 
-controller::controller() : v(0), urlcfg(0), rsscache(0), url_file("urls"), cache_file("cache.db"), config_file("config"), queue_file("queue"), refresh_on_start(false), api(0) {
-	char * cfgdir;
-	if (!(cfgdir = ::getenv("HOME"))) {
+controller::controller() : v(0), urlcfg(0), rsscache(0), url_file("urls"), cache_file("cache.db"), config_file("config"), queue_file("queue"), refresh_on_start(false), api(0), offline_mode(false) {
+}
+
+
+/**
+ * \brief Try to setup XDG style dirs.
+ *
+ * returns false, if that fails
+ */
+bool controller::setup_dirs_xdg(const char *env_home) {
+	const char *env_xdg_config;
+	const char *env_xdg_data;
+	std::string xdg_config_dir;
+	std::string xdg_data_dir;
+
+	env_xdg_config = ::getenv("XDG_CONFIG_HOME");
+	if (env_xdg_config) {
+		xdg_config_dir = env_xdg_config;
+	} else {
+		xdg_config_dir = env_home;
+		xdg_config_dir.append(NEWSBEUTER_PATH_SEP);
+		xdg_config_dir.append(".config");
+	}
+
+	env_xdg_data = ::getenv("XDG_DATA_HOME");
+	if (env_xdg_data) {
+		xdg_data_dir = env_xdg_data;
+	} else {
+		xdg_data_dir = env_home;
+		xdg_data_dir.append(NEWSBEUTER_PATH_SEP);
+		xdg_data_dir.append(".local");
+		xdg_data_dir.append(NEWSBEUTER_PATH_SEP);
+		xdg_data_dir.append("share");
+	}
+
+	xdg_config_dir.append(NEWSBEUTER_PATH_SEP);
+	xdg_config_dir.append(NEWSBEUTER_SUBDIR_XDG);
+
+	xdg_data_dir.append(NEWSBEUTER_PATH_SEP);
+	xdg_data_dir.append(NEWSBEUTER_SUBDIR_XDG);
+
+	if (access(xdg_config_dir.c_str(), R_OK | X_OK) != 0)
+	{
+		std::cout << utils::strprintf(_("XDG: configuration directory '%s' not accessible, using '%s' instead."), xdg_config_dir.c_str(), config_dir.c_str()) << std::endl;
+		return false;
+	}
+	if (access(xdg_data_dir.c_str(), R_OK | X_OK | W_OK) != 0)
+	{
+		std::cout << utils::strprintf(_("XDG: data directory '%s' not accessible, using '%s' instead."), xdg_data_dir.c_str(), config_dir.c_str()) << std::endl;
+		return false;
+	}
+
+	config_dir = xdg_config_dir;
+
+	/* in config */
+	url_file = config_dir + std::string(NEWSBEUTER_PATH_SEP) + url_file;
+	config_file = config_dir + std::string(NEWSBEUTER_PATH_SEP) + config_file;
+
+	/* in data */
+	cache_file = xdg_data_dir + std::string(NEWSBEUTER_PATH_SEP) + cache_file;
+	lock_file = cache_file + LOCK_SUFFIX;
+	queue_file = xdg_data_dir + std::string(NEWSBEUTER_PATH_SEP) + queue_file;
+	searchfile = utils::strprintf("%s%shistory.search", xdg_data_dir.c_str(), NEWSBEUTER_PATH_SEP);
+	cmdlinefile = utils::strprintf("%s%shistory.cmdline", xdg_data_dir.c_str(), NEWSBEUTER_PATH_SEP);
+
+	return true;
+}
+
+void controller::setup_dirs() {
+	const char * env_home;
+	if (!(env_home = ::getenv("HOME"))) {
 		struct passwd * spw = ::getpwuid(::getuid());
 		if (spw) {
-			cfgdir = spw->pw_dir;
+			env_home = spw->pw_dir;
 		} else {
 			std::cout << _("Fatal error: couldn't determine home directory!") << std::endl;
 			std::cout << utils::strprintf(_("Please set the HOME environment variable or add a valid user for UID %u!"), ::getuid()) << std::endl;
 			::exit(EXIT_FAILURE);
 		}
 	}
-	config_dir = cfgdir;
 
+	config_dir = env_home;
 	config_dir.append(NEWSBEUTER_PATH_SEP);
 	config_dir.append(NEWSBEUTER_CONFIG_SUBDIR);
+
+	if (setup_dirs_xdg(env_home))
+		return;
+
 	mkdir(config_dir.c_str(),0700); // create configuration directory if it doesn't exist
+
+	url_file = config_dir + std::string(NEWSBEUTER_PATH_SEP) + url_file;
+	cache_file = config_dir + std::string(NEWSBEUTER_PATH_SEP) + cache_file;
+	lock_file = cache_file + LOCK_SUFFIX;
+	config_file = config_dir + std::string(NEWSBEUTER_PATH_SEP) + config_file;
+	queue_file = config_dir + std::string(NEWSBEUTER_PATH_SEP) + queue_file;
+
+	searchfile = utils::strprintf("%s%shistory.search", config_dir.c_str(), NEWSBEUTER_PATH_SEP);
+	cmdlinefile = utils::strprintf("%s%shistory.cmdline", config_dir.c_str(), NEWSBEUTER_PATH_SEP);
 }
 
 controller::~controller() {
@@ -116,11 +197,7 @@ void controller::set_view(view * vv) {
 void controller::run(int argc, char * argv[]) {
 	int c;
 
-	url_file = config_dir + std::string(NEWSBEUTER_PATH_SEP) + url_file;
-	cache_file = config_dir + std::string(NEWSBEUTER_PATH_SEP) + cache_file;
-	lock_file = cache_file + LOCK_SUFFIX;
-	config_file = config_dir + std::string(NEWSBEUTER_PATH_SEP) + config_file;
-	queue_file = config_dir + std::string(NEWSBEUTER_PATH_SEP) + queue_file;
+	setup_dirs();
 
 	::signal(SIGINT, ctrl_c_action);
 	::signal(SIGPIPE, ignore_signal);
@@ -128,7 +205,7 @@ void controller::run(int argc, char * argv[]) {
 	::signal(SIGCHLD, omg_a_child_died);
 
 	bool do_import = false, do_export = false, cachefile_given_on_cmdline = false, do_vacuum = false;
-	bool offline_mode = false, real_offline_mode = false;
+	bool real_offline_mode = false;
 	std::string importfile;
 	bool do_read_import = false, do_read_export = false;
 	std::string readinfofile;
@@ -138,7 +215,7 @@ void controller::run(int argc, char * argv[]) {
 	bool execute_cmds = false;
 
 	do {
-		if((c = ::getopt(argc,argv,"i:erhu:c:C:d:l:vVoxXI:E:"))<0)
+		if((c = ::getopt(argc,argv,"i:erhqu:c:C:d:l:vVoxXI:E:"))<0)
 			continue;
 		switch (c) {
 			case ':': /* fall-through */
@@ -189,6 +266,9 @@ void controller::run(int argc, char * argv[]) {
 				execute_cmds = true;
 				silent = true;
 				break;
+			case 'q':
+				silent = true;
+				break;
 			case 'd': // this is an undocumented debug commandline option!
 				GetLogger().set_logfile(optarg);
 				break;
@@ -252,9 +332,6 @@ void controller::run(int argc, char * argv[]) {
 		}
 	}
 
-	std::string searchfile = utils::strprintf("%s%shistory.search", config_dir.c_str(), NEWSBEUTER_PATH_SEP);
-	std::string cmdlinefile = utils::strprintf("%s%shistory.cmdline", config_dir.c_str(), NEWSBEUTER_PATH_SEP);
-
 	if (!silent)
 		std::cout << _("Loading configuration...");
 	std::cout.flush();
@@ -334,15 +411,12 @@ void controller::run(int argc, char * argv[]) {
 	std::string type = cfg.get_configvalue("urls-source");
 	if (type == "local") {
 		urlcfg = new file_urlreader(url_file);
-	} else if (type == "bloglines") {
-		urlcfg = new bloglines_urlreader(&cfg);
-		real_offline_mode = offline_mode;
 	} else if (type == "opml") {
 		urlcfg = new opml_urlreader(&cfg);
 		real_offline_mode = offline_mode;
 	} else if (type == "googlereader") {
 		api = new googlereader_api(&cfg);
-		urlcfg = new googlereader_urlreader(&cfg, api);
+		urlcfg = new googlereader_urlreader(&cfg, url_file, api);
 		real_offline_mode = offline_mode;
 	} else {
 		LOG(LOG_ERROR,"unknown urls-source `%s'", urlcfg->get_source().c_str());
@@ -374,6 +448,19 @@ void controller::run(int argc, char * argv[]) {
 		if (!do_export && !silent) {
 			std::cout << _("done.") << std::endl;
 		}
+		if (api && type == "googlereader") { // ugly hack!
+			std::vector<google_replay_pair> actions = rsscache->get_google_replay();
+			if (actions.size() > 0) {
+				std::cout << _("Updating Google Reader unread states...");
+				std::cout.flush();
+
+				std::vector<std::string> successful_guids = dynamic_cast<googlereader_api *>(api)->bulk_mark_articles_read(actions);
+
+				rsscache->delete_google_replay_by_guid(successful_guids);
+
+				std::cout << _("done.") << std::endl;
+			}
+		}
 	}
 
 	if (urlcfg->get_urls().size() == 0) {
@@ -381,8 +468,6 @@ void controller::run(int argc, char * argv[]) {
 		std::string msg;
 		if (type == "local") {
 			msg = utils::strprintf(_("Error: no URLs configured. Please fill the file %s with RSS feed URLs or import an OPML file."), url_file.c_str());
-		} else if (type == "bloglines") {
-			msg = utils::strprintf(_("It looks like you haven't configured any feeds in your bloglines account. Please do so, and try again."));
 		} else if (type == "opml") {
 			msg = utils::strprintf(_("It looks like the OPML feed you subscribed contains no feeds. Please fill it with feeds, and try again."));
 		} else if (type == "googlereader") {
@@ -504,14 +589,21 @@ void controller::run(int argc, char * argv[]) {
 	LOG(LOG_DEBUG, "controller::run: history-limit = %u", history_limit);
 	formaction::save_histories(searchfile, cmdlinefile, history_limit);
 
-	std::cout << _("Cleaning up cache...");
-	std::cout.flush();
+	if (!silent) {
+		std::cout << _("Cleaning up cache...");
+		std::cout.flush();
+	}
 	try {
 		scope_mutex feedslock(&feeds_mutex);
 		rsscache->cleanup_cache(feeds);
-		std::cout << _("done.") << std::endl;
+		if (!silent) {
+			std::cout << _("done.") << std::endl;
+		}
 	} catch (const dbexception& e) {
-		std::cout << _("failed: ") << e.what() << std::endl;
+		LOG(LOG_USERERROR, "Cleaning up cache failed: %s", e.what());
+		if (!silent) {
+			std::cout << _("failed: ") << e.what() << std::endl;
+		}
 	}
 
 	utils::remove_fs_lock(lock_file);
@@ -550,10 +642,24 @@ void controller::catchup_all() {
 
 void controller::mark_article_read(const std::string& guid, bool read) {
 	if (api) {
-		api->mark_article_read(guid, read);
+		if (offline_mode) {
+			if (dynamic_cast<googlereader_api *>(api) != NULL) {
+				LOG(LOG_DEBUG, "controller::mark_article_read: recording %s", guid.c_str());
+				record_google_replay(guid, read);
+			} else {
+				LOG(LOG_DEBUG, "not on googlereader_api");
+			}
+		} else {
+			api->mark_article_read(guid, read);
+		}
 	}
 }
 
+void controller::record_google_replay(const std::string& guid, bool read) {
+	rsscache->record_google_replay(guid, read ? GOOGLE_MARK_READ : GOOGLE_MARK_UNREAD);
+}
+
+
 void controller::mark_all_read(unsigned int pos) {
 	if (pos < feeds.size()) {
 		scope_measure m("controller::mark_all_read");
@@ -716,6 +822,9 @@ void controller::reload_all(bool unattended) {
 		}
 	}
 
+	sort_feeds();
+	update_feedlist();
+
 	t2 = time(NULL);
 	dt = t2 - t1;
 	LOG(LOG_INFO, "controller::reload_all: reload took %d seconds", dt);
@@ -832,7 +941,8 @@ void controller::usage(char * argv0) {
 		{ 'C', _("<configfile>"), _("read configuration from <configfile>") },
 		{ 'X', "", _("clean up cache thoroughly") },
 		{ 'x', _("<command>..."), _("execute list of commands") },
-		{ 'o', "", _("activate offline mode (only applies to bloglines synchronization mode)") },
+		{ 'o', "", _("activate offline mode (only applies to Google Reader synchronization mode)") },
+		{ 'q', "", _("quiet startup") },
 		{ 'v', "", _("get version information") },
 		{ 'l', _("<loglevel>"), _("write a log with a certain loglevel (valid values: 1 to 6)") },
 		{ 'd', _("<logfile>"), _("use <logfile> as output log file") },
@@ -919,6 +1029,28 @@ void controller::rec_find_rss_outlines(xmlNode * node, std::string tag) {
 			if (url) {
 				LOG(LOG_DEBUG,"OPML import: found RSS outline with url = %s",url);
 
+				std::string nurl = std::string(url);
+
+				// Liferea uses a pipe to signal feeds read from the output of
+				// a program in its OPMLs. Convert them to our syntax.
+				if (*url == '|') {
+					nurl = utils::strprintf("exec:%s", url+1);
+					LOG(LOG_DEBUG,"OPML import: liferea-style url %s converted to %s", url, nurl.c_str());
+				}
+
+				// Handle OPML filters.
+				char * filtercmd = (char *)xmlGetProp(node, (const xmlChar *)"filtercmd");
+				if (filtercmd) {
+					LOG(LOG_DEBUG,"OPML import: adding filter command %s to url %s", filtercmd, nurl.c_str());
+					nurl.insert(0, utils::strprintf("filter:%s:", filtercmd));
+					xmlFree(filtercmd);
+				}
+
+				xmlFree(url);
+				// Filters and scripts may have arguments, so, quote them when needed.
+				url = (char*) xmlStrdup((const xmlChar*)utils::quote_if_necessary(nurl).c_str());
+				assert(url);
+
 				bool found = false;
 
 				LOG(LOG_DEBUG, "OPML import: size = %u", urlcfg->get_urls().size());
@@ -1162,6 +1294,12 @@ void controller::write_item(std::tr1::shared_ptr<rss_item> item, std::ostream& o
 	std::string link(_("Link: "));
 	link.append(item->link());
 	lines.push_back(link);
+
+	if (item->enclosure_url() != "") {
+		std::string dlurl(_("Podcast Download URL: "));
+		dlurl.append(item->enclosure_url());
+		lines.push_back(dlurl);
+	}
 	
 	lines.push_back(std::string(""));
 	
@@ -1198,8 +1336,10 @@ void controller::save_feed(std::tr1::shared_ptr<rss_feed> feed, unsigned int pos
 		LOG(LOG_DEBUG, "controller::reload: after internalize_rssfeed");
 		feed->set_tags(urlcfg->get_tags(feed->rssurl()));
 		{
+			unsigned int order = feeds[pos]->get_order();
 			scope_mutex itemlock(&feeds[pos]->item_mutex);
 			feeds[pos]->items().clear();
+			feed->set_order(order);
 		}
 		feeds[pos] = feed;
 		v->notify_itemlist_change(feeds[pos]);
