@@ -1,5 +1,6 @@
 #include <vector>
 #include <cstring>
+#include <iostream>
 
 #include <google_api.h>
 #include <config.h>
@@ -42,8 +43,22 @@ static size_t my_write_data(void *buffer, size_t size, size_t nmemb, void *userp
 
 std::string googlereader_api::retrieve_auth() {
 	CURL * handle = curl_easy_init();
+	std::string pass = cfg->get_configvalue("googlereader-password");
+	if( pass == "" ) {
+		std::cout << std::endl;
+		std::cout.flush();
+		// Find a way to do this in C++ by removing cin echoing.
+		pass = std::string( getpass("Password for Google Reader: ") );
+	}
+	char * username = curl_easy_escape(handle, cfg->get_configvalue("googlereader-login").c_str(), 0);
+	char * password = curl_easy_escape(handle, pass.c_str(), 0);
+
 	std::string postcontent = utils::strprintf("service=reader&Email=%s&Passwd=%s&source=%s/%s&continue=http://www.google.com/", 
-		cfg->get_configvalue("googlereader-login").c_str(), cfg->get_configvalue("googlereader-password").c_str(), PROGRAM_NAME, PROGRAM_VERSION);
+		username, password, PROGRAM_NAME, PROGRAM_VERSION);
+
+	curl_free(username);
+	curl_free(password);
+
 	std::string result;
 
 	utils::set_common_curl_options(handle, cfg);
@@ -172,8 +187,31 @@ bool googlereader_api::mark_all_read(const std::string& feedurl) {
 	return result == "OK";
 }
 
+std::vector<std::string> googlereader_api::bulk_mark_articles_read(const std::vector<google_replay_pair>& actions) {
+	std::vector<std::string> successful_tokens;
+	std::string token = get_new_token();
+	for (std::vector<google_replay_pair>::const_iterator it=actions.begin();it!=actions.end();it++) {
+		bool read;
+		if (it->second == GOOGLE_MARK_READ) {
+			read = true;
+		} else if (it->second == GOOGLE_MARK_UNREAD) {
+			read = false;
+		} else {
+			continue;
+		}
+		if (mark_article_read_with_token(it->first, read, token)) {
+			successful_tokens.push_back(it->first);
+		}
+	}
+	return successful_tokens;
+}
+
 bool googlereader_api::mark_article_read(const std::string& guid, bool read) {
 	std::string token = get_new_token();
+	return mark_article_read_with_token(guid, read, token);
+}
+
+bool googlereader_api::mark_article_read_with_token(const std::string& guid, bool read, const std::string& token) {
 	std::string postcontent;
 
 	if (read) {
@@ -184,7 +222,7 @@ bool googlereader_api::mark_article_read(const std::string& guid, bool read) {
 
 	std::string result = post_content(GREADER_API_EDIT_TAG_URL, postcontent);
 
-	LOG(LOG_DEBUG, "googlereader_api::mark_article_read: postcontent = %s result = %s", postcontent.c_str(), result.c_str());
+	LOG(LOG_DEBUG, "googlereader_api::mark_article_read_with_token: postcontent = %s result = %s", postcontent.c_str(), result.c_str());
 
 	return result == "OK";
 }
