@@ -83,6 +83,7 @@ void itemlist_formaction::process_operation(operation op, bool automatic, std::v
 				if (itemposname.length() > 0 && visible_items.size() != 0) {
 					if (itempos < visible_items.size()) {
 						visible_items[itempos].first->set_unread(false);
+						v->get_ctrl()->mark_article_read(visible_items[itempos].first->guid(), true);
 						if (itempos < visible_items.size()-1) {
 							f->set("itempos", utils::strprintf("%u", itempos + 1));
 						}
@@ -114,12 +115,16 @@ void itemlist_formaction::process_operation(operation op, bool automatic, std::v
 						if (automatic && args->size() > 0) {
 							if ((*args)[0] == "read") {
 								visible_items[itempos].first->set_unread(false);
+								v->get_ctrl()->mark_article_read(visible_items[itempos].first->guid(), true);
 							} else if ((*args)[0] == "unread") {
 								visible_items[itempos].first->set_unread(true);
+								v->get_ctrl()->mark_article_read(visible_items[itempos].first->guid(), false);
 							}
 							v->set_status("");
 						} else {
-							visible_items[itempos].first->set_unread(!visible_items[itempos].first->unread());
+							bool unread = visible_items[itempos].first->unread();
+							visible_items[itempos].first->set_unread(!unread);
+							v->get_ctrl()->mark_article_read(visible_items[itempos].first->guid(), unread);
 							v->set_status("");
 						}
 					} catch (const dbexception& e) {
@@ -198,7 +203,7 @@ void itemlist_formaction::process_operation(operation op, bool automatic, std::v
 							filename = (*args)[0];
 						}
 					} else {
-						filename = v->run_filebrowser(FBT_SAVE,v->get_filename_suggestion(visible_items[itempos].first->title()));
+						filename = v->run_filebrowser(v->get_filename_suggestion(visible_items[itempos].first->title()));
 					}
 					save_article(filename, visible_items[itempos].first);
 				} else {
@@ -223,6 +228,7 @@ void itemlist_formaction::process_operation(operation op, bool automatic, std::v
 			LOG(LOG_INFO, "itemlist_formaction: quitting");
 			v->feedlist_mark_pos_if_visible(pos);
 			feed->purge_deleted_items();
+			feed->unload();
 			quit = true;
 			break;
 		case OP_HARDQUIT:
@@ -247,6 +253,22 @@ void itemlist_formaction::process_operation(operation op, bool automatic, std::v
 				}
 			}
 			break;
+		case OP_NEXT:
+			LOG(LOG_INFO, "itemlist_formaction: jumping to next item");
+			if (!jump_to_next_item(false)) {
+				if (!v->get_next(this)) {
+					v->show_error(_("Already on last item."));
+				}
+			}
+			break;
+		case OP_PREV:
+			LOG(LOG_INFO, "itemlist_formaction: jumping to previous item");
+			if (!jump_to_previous_item(false)) {
+				if (!v->get_previous(this)) {
+					v->show_error(_("Already on first item."));
+				}
+			}
+			break;
 		case OP_RANDOMUNREAD:
 			if (!jump_to_random_unread_item()) {
 				if (!v->get_random_unread(this)) {
@@ -254,16 +276,26 @@ void itemlist_formaction::process_operation(operation op, bool automatic, std::v
 				}
 			}
 			break;
-		case OP_NEXTFEED:
+		case OP_NEXTUNREADFEED:
 			if (!v->get_next_unread_feed(this)) {
 				v->show_error(_("No unread feeds."));
 			}
 			break;
-		case OP_PREVFEED:
+		case OP_PREVUNREADFEED:
 			if (!v->get_prev_unread_feed(this)) {
 				v->show_error(_("No unread feeds."));
 			}
 			break;
+		case OP_NEXTFEED:
+			if (!v->get_next_feed(this)) {
+				v->show_error(_("Already on last feed."));
+			}
+			break;
+		case OP_PREVFEED:
+			if (!v->get_prev_feed(this)) {
+				v->show_error(_("Already on first feed."));
+			}
+			break;
 		case OP_MARKFEEDREAD:
 			LOG(LOG_INFO, "itemlist_formaction: marking feed read");
 			v->set_status(_("Marking feed read..."));
@@ -275,7 +307,7 @@ void itemlist_formaction::process_operation(operation op, bool automatic, std::v
 						scope_mutex lock(&feed->item_mutex);
 						LOG(LOG_DEBUG, "itemlist_formaction: oh, it looks like I'm in a pseudo-feed (search result, query feed)");
 						for (std::vector<std::tr1::shared_ptr<rss_item> >::iterator it=feed->items().begin();it!=feed->items().end();++it) {
-							(*it)->set_unread_nowrite_notify(false, true);
+							(*it)->set_unread_nowrite_notify(false, true); // TODO: do we need to call mark_article_read here, too?
 						}
 					}
 					v->get_ctrl()->catchup_all(feed);
@@ -331,6 +363,9 @@ void itemlist_formaction::process_operation(operation op, bool automatic, std::v
 				}
 			}
 			break;
+		case OP_EDIT_URLS:
+			v->get_ctrl()->edit_urls_file();
+			break;
 		case OP_SELECTFILTER:
 			if (v->get_ctrl()->get_filters().size() > 0) {
 				std::string newfilter;
@@ -755,6 +790,45 @@ bool itemlist_formaction::jump_to_next_unread_item(bool start_with_first) {
 	return false;
 }
 
+bool itemlist_formaction::jump_to_previous_item(bool start_with_last) {
+	int itempos;
+	std::istringstream is(f->get("itempos"));
+	is >> itempos;
+	for (int i=(start_with_last?itempos:(itempos-1));i>=0;--i) {
+		LOG(LOG_DEBUG, "itemlist_formaction::jump_to_previous_item: visible_items[%u]", i);
+		f->set("itempos", utils::to_s(i));
+		return true;
+	}
+	return false; // not sure if we should exit here or continue
+	// wrap to last item
+	for (int i=visible_items.size()-1;i>=itempos;--i) {
+		f->set("itempos", utils::to_s(i));
+		return true;
+	}
+	return false;
+
+}
+
+bool itemlist_formaction::jump_to_next_item(bool start_with_first) {
+	unsigned int itempos;
+	std::istringstream is(f->get("itempos"));
+	is >> itempos;
+	LOG(LOG_DEBUG, "itemlist_formaction::jump_to_next_item: itempos = %u visible_items.size = %u", itempos, visible_items.size());
+	for (unsigned int i=(start_with_first?itempos:(itempos+1));i<visible_items.size();++i) {
+		LOG(LOG_DEBUG, "itemlist_formaction::jump_to_next_item: i = %u", i);
+		f->set("itempos", utils::to_s(i));
+		return true;
+	}
+	return false; // not sure if we should exit here or continue
+	// wrap to first item
+	for (unsigned int i=0;i<=itempos;++i) {
+		LOG(LOG_DEBUG, "itemlist_formaction::jump_to_next_item: i = %u", i);
+		f->set("itempos", utils::to_s(i));
+		return true;
+	}
+	return false;
+}
+
 std::string itemlist_formaction::get_guid() {
 	unsigned int itempos;
 	std::istringstream is(f->get("itempos"));
@@ -919,7 +993,8 @@ void itemlist_formaction::prepare_set_filterpos() {
 
 void itemlist_formaction::set_feed(std::tr1::shared_ptr<rss_feed> fd) {
 	LOG(LOG_DEBUG, "itemlist_formaction::set_feed: fd pointer = %p title = `%s'", fd.get(), fd->title().c_str());
-	feed = fd; 
+	feed = fd;
+	feed->load();
 	update_visible_items = true; 
 	do_update_visible_items();
 }
