@@ -29,6 +29,8 @@ bool matcher::parse(const std::string& expr) {
 	struct timeval tv1, tv2;
 	gettimeofday(&tv1, NULL);
 
+	errmsg = "";
+
 	bool b = p.parse_string(expr);
 
 	if (!b) {
@@ -83,7 +85,7 @@ bool matcher::matchop_between(expression * e, matchable * item) {
 	std::istringstream isatt(item->get_attribute(e->name));
 	int att;
 	isatt >> att;
-	if (lit.size() != 2)
+	if (lit.size() < 2)
 		return false;
 	std::istringstream is1(lit[0]), is2(lit[1]);
 	int i1, i2, tmp;
@@ -190,9 +192,6 @@ bool matcher::matches_r(expression * e, matchable * item) {
 			case MATCHOP_CONTAINSNOT:
 				return !matchop_cont(e, item);
 
-			default:
-				LOG(LOG_ERROR, "matcher::matches_r: invalid operator %d", e->op);
-				assert(false); // that's an error condition
 		}
 		return false;
 	} else {
