@@ -81,15 +81,6 @@ std::string rss_parser::render_xhtml_title(const std::string& title, const std::
 	return "";
 }
 
-unsigned int rss_parser::monthname_to_number(const std::string& monthstr) {
-	static const char * monthtable[] = { "Jan", "Feb", "Mar", "Apr","May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec", NULL };
-	for (unsigned int i=0;monthtable[i]!=NULL;i++) {
-		if (monthstr == monthtable[i])
-			return i;
-	}
-	return 0;
-}
-
 void rss_parser::set_rtl(std::tr1::shared_ptr<rss_feed> feed, const char * lang) {
 	// we implement right-to-left support for the languages listed in
 	// http://blogs.msdn.com/rssteam/archive/2007/05/17/reading-feeds-in-right-to-left-order.aspx
@@ -112,12 +103,6 @@ void rss_parser::set_rtl(std::tr1::shared_ptr<rss_feed> feed, const char * lang)
 	}
 }
 
-int rss_parser::correct_year(int year) {
-	if (year < 100)
-		year += 2000;
-	return year - 1900;
-}
-
 void rss_parser::retrieve_uri(const std::string& uri) {
 	/*
 	 *	- http:// and https:// URLs are downloaded and parsed regularly
@@ -164,7 +149,8 @@ void rss_parser::download_http(const std::string& uri) {
 			if (!ign || !ign->matches_lastmodified(uri)) {
 				ch->fetch_lastmodified(uri, lm, etag);
 			}
-			f = p.parse_url(uri, lm, etag, api);
+			f = p.parse_url(uri, lm, etag, api, cfgcont->get_configvalue("cookie-cache"));
+			LOG(LOG_DEBUG, "rss_parser::download_http: lm = %d etag = %s", p.get_last_modified(), p.get_etag().c_str());
 			if (p.get_last_modified() != 0 || p.get_etag().length() > 0) {
 				LOG(LOG_DEBUG, "rss_parser::download_http: lastmodified old: %d new: %d", lm, p.get_last_modified());
 				LOG(LOG_DEBUG, "rss_parser::download_http: etag old: %s new %s", etag.c_str(), p.get_etag().c_str());
