@@ -7,6 +7,7 @@
 #include <sstream>
 #include <iostream>
 #include <cstdlib>
+#include <algorithm>
 
 #include <config.h>
 
@@ -113,6 +114,7 @@ void tagsouppullparser::add_attribute(std::string s) {
 		attribname = attribvalue = s;
 	}
 	attribvalue = decode_attribute(attribvalue);
+	std::transform(attribname.begin(), attribname.end(), attribname.begin(), ::tolower);
 	attributes.push_back(attribute(attribname,attribvalue));
 }
 
@@ -474,12 +476,6 @@ std::string tagsouppullparser::decode_entity(std::string s) {
 	return ""; 	
 }
 
-void tagsouppullparser::remove_trailing_whitespace(std::string& s) {
-	while (s.length() > 0 && isspace(s[s.length()-1])) {
-		s.erase(s.length()-1,1);
-	}
-}
-
 void tagsouppullparser::parse_tag(const std::string& tagstr) {
 	std::string::size_type last_pos = tagstr.find_first_not_of(" \r\n\t", 0);
 	std::string::size_type pos = tagstr.find_first_of(" \r\n\t", last_pos);
@@ -502,7 +498,7 @@ void tagsouppullparser::parse_tag(const std::string& tagstr) {
 				if (tagstr[pos] == '=') {
 					LOG(LOG_DEBUG, "parse_tag: found =");
 					if (tagstr[pos+1] == '\'' || tagstr[pos+1] == '"') {
-						pos = tagstr.find_first_of("'\"", pos+2);
+						pos = tagstr.find_first_of(tagstr[pos+1], pos+2);
 						if (pos != std::string::npos)
 							pos++;
 						LOG(LOG_DEBUG, "parse_tag: finding ending quote, pos = %d", pos);
