@@ -507,13 +507,12 @@ void view::push_urlview(const std::vector<linkpair>& links) {
 	current_formaction = formaction_stack_size() - 1;
 }
 
-std::string view::run_filebrowser(filebrowser_type type, const std::string& default_filename, const std::string& dir) {
+std::string view::run_filebrowser(const std::string& default_filename, const std::string& dir) {
 	std::tr1::shared_ptr<filebrowser_formaction> filebrowser(new filebrowser_formaction(this, filebrowser_str));
 	set_bindings(filebrowser);
 	apply_colors(filebrowser);
 	filebrowser->set_dir(dir);
 	filebrowser->set_default_filename(default_filename);
-	filebrowser->set_type(type);
 	filebrowser->set_parent_formaction(get_current_formaction());
 	return run_modal(filebrowser, "filenametext");
 }
@@ -699,6 +698,94 @@ bool view::get_next_unread(itemlist_formaction * itemlist, itemview_formaction *
 	return false;
 }
 
+bool view::get_previous(itemlist_formaction * itemlist, itemview_formaction * itemview) {
+	unsigned int feedpos;
+	std::tr1::shared_ptr<feedlist_formaction> feedlist = std::tr1::dynamic_pointer_cast<feedlist_formaction, formaction>(formaction_stack[0]);
+	if (itemlist->jump_to_previous_item(false)) {
+		LOG(LOG_DEBUG, "view::get_previous: article in same feed");
+		if (itemview) {
+			itemview->init();
+			itemview->set_feed(itemlist->get_feed());
+			itemview->set_guid(itemlist->get_guid());
+		}
+		return true;
+	} else if (cfg->get_configvalue_as_bool("goto-next-feed")==false) {
+		LOG(LOG_DEBUG, "view::get_previous: goto-next-feed = false");
+		show_error(_("Already on first item."));
+	} else if (feedlist->jump_to_previous_feed(feedpos)) {
+		LOG(LOG_DEBUG, "view::get_previous: previous feed");
+		itemlist->set_feed(feedlist->get_feed());
+		itemlist->set_pos(feedpos);
+		itemlist->init();
+		if (itemlist->jump_to_previous_item(true)) {
+			if (itemview) {
+				itemview->init();
+				itemview->set_feed(itemlist->get_feed());
+				itemview->set_guid(itemlist->get_guid());
+			}
+			return true;
+		}
+	}
+	return false;
+}
+
+bool view::get_next(itemlist_formaction * itemlist, itemview_formaction * itemview) {
+	unsigned int feedpos;
+	std::tr1::shared_ptr<feedlist_formaction> feedlist = std::tr1::dynamic_pointer_cast<feedlist_formaction, formaction>(formaction_stack[0]);
+	if (itemlist->jump_to_next_item(false)) {
+		LOG(LOG_DEBUG, "view::get_next: article in same feed");
+		if (itemview) {
+			itemview->init();
+			itemview->set_feed(itemlist->get_feed());
+			itemview->set_guid(itemlist->get_guid());
+		}
+		return true;
+	} else if (cfg->get_configvalue_as_bool("goto-next-feed")==false) {
+		LOG(LOG_DEBUG, "view::get_next: goto-next-feed = false");
+		show_error(_("Already on last item."));
+	} else if (feedlist->jump_to_next_feed(feedpos)) {
+		LOG(LOG_DEBUG, "view::get_next: next feed");
+		itemlist->set_feed(feedlist->get_feed());
+		itemlist->set_pos(feedpos);
+		itemlist->init();
+		if (itemlist->jump_to_next_item(true)) {
+			if (itemview) {
+				itemview->init();
+				itemview->set_feed(itemlist->get_feed());
+				itemview->set_guid(itemlist->get_guid());
+			}
+			return true;
+		}
+	}
+	return false;
+}
+
+bool view::get_next_feed(itemlist_formaction * itemlist) {
+	std::tr1::shared_ptr<feedlist_formaction> feedlist = std::tr1::dynamic_pointer_cast<feedlist_formaction, formaction>(formaction_stack[0]);
+	unsigned int feedpos;
+	assert(feedlist != NULL);
+	if (feedlist->jump_to_next_feed(feedpos)) {
+		itemlist->set_feed(feedlist->get_feed());
+		itemlist->set_pos(feedpos);
+		itemlist->init();
+		return true;
+	}
+	return false;
+}
+
+bool view::get_prev_feed(itemlist_formaction * itemlist) {
+	std::tr1::shared_ptr<feedlist_formaction> feedlist = std::tr1::dynamic_pointer_cast<feedlist_formaction, formaction>(formaction_stack[0]);
+	unsigned int feedpos;
+	assert(feedlist != NULL);
+	if (feedlist->jump_to_previous_feed(feedpos)) {
+		itemlist->set_feed(feedlist->get_feed());
+		itemlist->set_pos(feedpos);
+		itemlist->init();
+		return true;
+	}
+	return false;
+}
+
 void view::pop_current_formaction() {
 	std::tr1::shared_ptr<formaction> f = get_current_formaction();
 	std::vector<std::tr1::shared_ptr<formaction> >::iterator it=formaction_stack.begin();
@@ -832,13 +919,6 @@ void view::apply_colors(std::tr1::shared_ptr<formaction> fa) {
 	}
 }
 
-std::string view::id() {
-	if (formaction_stack.size() > 0) {
-		return get_current_formaction()->id();
-	}
-	return "";
-}
-
 void view::feedlist_mark_pos_if_visible(unsigned int pos) {
 	if (formaction_stack_size() > 0) {
 		std::tr1::dynamic_pointer_cast<feedlist_formaction, formaction>(formaction_stack[0])->mark_pos_if_visible(pos);
